/*
 * Targeted Advertising Cookie Opt-Out
 * Copyright 2009, Christopher Soghoian
 * www.dubfire.net
 *
 *
 * Based on the Advertising Cookie Opt-out Plugin.
 * which was written by vali@google.com (Valentin Gheorghita)
 * Available here: http://www.google.com/ads/preferences/plugin/
 * That code is copyright 2009 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * Check if third party cookies are disabled.
 * @return {boolean} True if they are disabled.
 */
function AdvertisingOptOut_ThirdPartyCookiesDisabled() {
  return Components.classes['@mozilla.org/preferences-service;1'].
      getService(Components.interfaces.nsIPrefBranch).
      getIntPref('network.cookie.cookieBehavior') != 0;
}

/**
 * Check if the user should be opt out, and in affirmative case the cookie
 * is installed.
 */
function AdvertisingOptOut_OptOut() {
  if (!AdvertisingOptOut_ThirdPartyCookiesDisabled()) {
    var ios = Components.classes['@mozilla.org/network/io-service;1'].
        getService(Components.interfaces.nsIIOService);
    var prefService = Components.classes['@mozilla.org/preferences-service;1'].
        getService(Components.interfaces.nsIPrefService);
    var prefOptOut = prefService.getBranch('extensions.advertisingoptout.');


    /* Google / Doubleclick */ 
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('google.url'), null, null);
    var cookieSvc = Components.classes['@mozilla.org/cookieService;1'].
        getService(Components.interfaces.nsICookieService);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('google.cookie'), null);

    /* Collective Media */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('collectivemedia.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('collectivemedia.cookie'), null);
    
    /* Acerno /  imiclk.com */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('imiclk.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('imiclk.cookie'), null);
    
    /* Turn */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('turn.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('turn.cookie'), null);
    
    /* Next Action / nexac.com */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('nexac.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('nexac.cookie'), null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('nexac.cookie2'), null);

    /* Audience Science / revsci.net */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('revsci.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('revsci.cookie'), null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('revsci.cookie2'), null);

    /* BlueLithium / adrevolver.net */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('adrevolver.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('adrevolver.cookie'), null);
 

    /* Remove Advertising.com Cookies */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('advertisingcom.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('advertisingcom.cookie'), null);

    /* [x+1] / edge.ru4.net */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('ru4.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('ru4.cookie'), null);


    /* Fox Audience Network */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('fimserve.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('fimserve.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('optfimserve.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('optfimserve.cookie'), null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('optfimserve.cookie2'), null);


    /* AlmondNet / pro-market.net */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('promarket.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('promarket.cookie'), null);

    /* Safecount / questionmarket.com */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('questionmarket.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('questionmarket.cookie'), null);

    /* Tacoda Audience Networks */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('tacoda.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('tacoda.cookie'), null);

    /* Traffic Marketplace */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('trafficmp.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('trafficmp.cookie'), null);

    /* Tribal Fusion */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('tribalfusion.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('tribalfusion.cookie'), null);

    /* Undertone Networks / Zedo.com /  */
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('zedo.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('zedo.cookie'), null);

    // Cossette / adcentriconline.com
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('cossette.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('cossette.cookie'), null);
    // Adtech
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('adtech-de.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('adtech-de.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('glb-adtech-us.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('glb-adtech-us.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('wc-adtech-us.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('wc-adtech-us.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('ec-adtech-us.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('ec-adtech-us.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('ad-ec-adtech-us.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('ad-ec-adtech-us.cookie'), null);
    // Atlas / Microsoft
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('atlas.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('atlas.cookie'), null);
    // Bluestreak
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('bluestreak.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('bluestreak.cookie'), null);
    // Exelator
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('load-exelator-com.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('load-exelator-com.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadan-exelator-net.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadan-exelator-net.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadan-exelator-com.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadan-exelator-com.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadxl-exelator-net.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadxl-exelator-net.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadxl-exelator-com.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadxl-exelator-com.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadrs-exelator-com.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadrs-exelator-com.cookie'), null);
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('loadxl-exelator-biz.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('loadxl-exelator-biz.cookie'), null);

    // Eyeblaster /  serving-sys.com
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('eyeblaster.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('eyeblaster.cookie'), null);

    // ValueClick / Mediaplex
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('valueclick.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('valueclick.cookie'), null);
    // Mindset Media / mmismm.com
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('mindset.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('mindset.cookie'), null);
    // OpenX
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('openx.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('openx.cookie'), null);
    // precisionclick
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('precisionclick.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('precisionclick.cookie'), null);

    // Smart Adserver
    var cookieUri = ios.newURI(
        prefOptOut.getCharPref('smartadserver.url'), null, null);
    cookieSvc.setCookieString(cookieUri, null,
                              prefOptOut.getCharPref('smartadserver.cookie'), null);


  }
}

/**
 * Listener variable for cookie deleted.
 */
var AdvertisingOptOut_CookieListener =
{
  observe: function(subject, topic, data) {
    if (topic == 'cookie-changed') {
      if (data == 'cleared' || data == 'deleted') {
        AdvertisingOptOut_OptOut();
      }
    }
  }
};

/**
 * Load the extension.
 */
function AdvertisingOptOut_Load() {
  Components.classes['@mozilla.org/observer-service;1'].
      getService(Components.interfaces.nsIObserverService).
      addObserver(AdvertisingOptOut_CookieListener, 'cookie-changed', false);
  var period = Components.classes['@mozilla.org/preferences-service;1'].
      getService(Components.interfaces.nsIPrefBranch).
      getIntPref('extensions.advertisingoptout.checkPeriodInS');
  window.setInterval(AdvertisingOptOut_OptOut, period * 1000);
  AdvertisingOptOut_OptOut();
}

/**
 * Unload the extension.
 */
function AdvertisingOptOut_Unload() {
  Components.classes['@mozilla.org/observer-service;1'].
      getService(Components.interfaces.nsIObserverService).
      removeObserver(AdvertisingOptOut_CookieListener, 'cookie-changed');
}
